searchData={"items":[{"type":"module","doc":"","title":"PerceptibleId","ref":"PerceptibleId.html"},{"type":"function","doc":"Returns the default character set used to generate the ID.","title":"PerceptibleId.charset/0","ref":"PerceptibleId.html#charset/0"},{"type":"function","doc":"Generates a perceptible ID. That defaults to:\n\n* 8 characters in length\n* 22 characters.","title":"PerceptibleId.generate/0","ref":"PerceptibleId.html#generate/0"},{"type":"function","doc":"iex> PerceptibleId.generate()\n    \"escyphtf\"","title":"Examples - PerceptibleId.generate/0","ref":"PerceptibleId.html#generate/0-examples"},{"type":"function","doc":"Generates a perceptible ID of `n` length.","title":"PerceptibleId.generate/2","ref":"PerceptibleId.html#generate/2"},{"type":"function","doc":"* `:include` - a list of characters to potentially include in the ID\n* `:exclude` - a list of characters to exclude from ID generation","title":"Options - PerceptibleId.generate/2","ref":"PerceptibleId.html#generate/2-options"},{"type":"function","doc":"iex> PerceptibleId.generate(12)\n    \"bawepsticymj\"\n\n    iex> PerceptibleId.generate(12, include: [\"7\", \"8\", \"9\"])\n    \"9d7jbowtps3y\"\n\n    iex> PerceptibleId.generate(12, include: [\"1\", \"2\", \"3\"], exclude: [\"h\", \"a\"])\n    \"3msdtj1wecri\"","title":"Examples - PerceptibleId.generate/2","ref":"PerceptibleId.html#generate/2-examples"},{"type":"extras","doc":"# Perceptible ID  [![Hex Version](https://img.shields.io/hexpm/v/perceptible_id.svg)](https://hex.pm/packages/perceptible_id) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/perceptible_id/)\n\nA customizable ID generator for Elixir which, by default, is limited to the following 22 English characters:\n\n```elixir\n[a, b, c, d, e, f, h, i, j, k, m, n, o, p, r, s, t, w, x, y, 3, 4]\n```\n\nInspired by [Understanding and avoiding visually ambiguous characters in IDs](https://gajus.com/blog/avoiding-visually-ambiguous-characters-in-ids#visually-unambiguous-dictionary).","title":"Perceptible ID","ref":"readme.html"},{"type":"extras","doc":"* Generate IDs with single function call\n* Generate IDs with custom lengths\n* Generate IDs with custom character inclusions and exclusions.\n* Reasonably performant. See [Benchmarks](#benchmarks).","title":"Features - Perceptible ID","ref":"readme.html#features"},{"type":"extras","doc":"* Elixir 1.17 or greater\n* Erlang OTP 27 or greater","title":"Requirements - Perceptible ID","ref":"readme.html#requirements"},{"type":"extras","doc":"The package can be installed by adding `perceptible_id` to your list\nof dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:perceptible_id, \"~> 1.0.0\"}\n  ]\nend\n```","title":"Installation - Perceptible ID","ref":"readme.html#installation"},{"type":"extras","doc":"Generating an ID with the default length and default characters from config:\n\n```elixir\niex> PerceptibleId.generate\n\"ipbx4ah3\"\n```\n\nGenerating an ID with a custom length:\n\n```elixir\niex> PerceptibleId.generate(12)\n\"cnhxie3sfdtp\"\n```\n\nGenerating an ID with a custom length, with potential inclusions and\nultimate exclusions:\n\n```elixir\niex> PerceptibleId.generate(12, include: [\"1\", \"2\", \"3\"], exclude: [\"a\", \"b\", \"c\"])\n\"npokwc3yfed2\"\n```","title":"Usage - Perceptible ID","ref":"readme.html#usage"},{"type":"extras","doc":"This is based on the default number of characters, which is `22`.\n\n| Character Length | Max Unique IDs         |\n|------------------|------------------------|\n| 1                | 22                     |\n| 2                | 484                    |\n| 3                | 10,648                 |\n| 4                | 234,256                |\n| 5                | 5,153,632              |\n| 6                | 113,379,904            |\n| 7                | 2,494,357,888          |\n| 8 (default)      | 54,875,873,536         |\n| 9                | 1,207,269,217,792      |\n| 10               | 26,559,922,791,424     |\n| 11               | 584,318,301,411,328    |\n| 12               | 12,855,002,631,049,216 |","title":"Maximum Possible IDs by Length - Perceptible ID","ref":"readme.html#maximum-possible-ids-by-length"},{"type":"extras","doc":"Internally, this is using Erlang's `rand` module to generate the\nIDs. It is using the default algorithm, [exsss](https://www.erlang.org/doc/apps/stdlib/rand.html#default-algorithm).","title":"Randomization Algorithm - Perceptible ID","ref":"readme.html#randomization-algorithm"},{"type":"extras","doc":"The following benchmark was run for IDs from length 8 to 12 with each test generating 10k IDs.\n\n```\n[1] % mix run benchmarks/general.exs\nOperating System: Linux\nCPU Information: AMD Ryzen 9 5950X 16-Core Processor\nNumber of Available Cores: 32\nAvailable memory: 31.26 GB\nElixir 1.17.1\nErlang 27.0\nJIT enabled: true\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 5 s\nmemory time: 0 ns\nreduction time: 0 ns\nparallel: 1\ninputs: none specified\nEstimated total run time: 35 s\n\nBenchmarking generate.10 ...\nBenchmarking generate.11 ...\nBenchmarking generate.12 ...\nBenchmarking generate.8 ...\nBenchmarking generate.9 ...\nCalculating statistics...\nFormatting results...\n\nName                  ips        average  deviation         median         99th %\ngenerate.8          28.87       34.64 ms     ±1.88%       34.49 ms       37.21 ms\ngenerate.10         28.22       35.44 ms     ±1.55%       35.29 ms       38.21 ms\ngenerate.11         27.02       37.01 ms     ±5.18%       36.07 ms       41.43 ms\ngenerate.12         26.82       37.29 ms     ±5.31%       36.25 ms       41.67 ms\ngenerate.9          26.52       37.71 ms     ±6.14%       36.48 ms       41.44 ms\n\nComparison:\ngenerate.8          28.87\ngenerate.10         28.22 - 1.02x slower +0.80 ms\ngenerate.11         27.02 - 1.07x slower +2.36 ms\ngenerate.12         26.82 - 1.08x slower +2.65 ms\ngenerate.9          26.52 - 1.09x slower +3.07 ms\n```\n\nYou can run this on your machine using `mix run benchmarks/general.exs`.","title":"Benchmarks - Perceptible ID","ref":"readme.html#benchmarks"},{"type":"extras","doc":"This software is licensed under the [Apache-2.0 License](LICENSE).","title":"License - Perceptible ID","ref":"readme.html#license"},{"type":"extras","doc":"# Changelog\n\nAll changes worthy of mention are noted here.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [1.0.0] - 2024-12-26","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"- Added inline docs + typespec public functions\n- Added tests for generation functions on the `PerceptibleId` module\n- Added `README` with documentation for basic installing and usage of this library\n- Added license (Apache 2.0) to project","title":"Added - Changelog","ref":"changelog.html#added"},{"type":"extras","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","title":"LICENSE","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}